@@ -52,8 +52,9 @@ class Bot:
 
         self.loop = asyncio.get_event_loop()
 
-    def add_chat_filter(self,chat_id:int):
+    def add_chat_filter(self, chat_id: int):
         self.chat_filter.append(chat_id)
+
     # <---- custom API actions start ----> #
 
     async def send_photo(self, chat_id, photo, **kwargs):
@@ -128,18 +129,19 @@ class Bot:
 
     # <---- COGS start ----> #
 
-    def command(self, name,aliases=None,usage=None,description=None, roles=None, ignore_filter=False):
+    def command(self, name, aliases=None, usage=None, description=None, roles=None, ignore_filter=False):
         def decorator(func):
-            command = Command(func,name,description,aliases,usage,roles,ignore_filter)
+            command = Command(func, name, description, aliases, usage, roles, ignore_filter)
             self.add_command(name, command)
             if ignore_filter:
                 self.ignore_filter.append(command)
             if aliases is not None:
                 for al in aliases:
-                    self.add_command(al,command)
+                    self.add_command(al, command)
+
         return decorator
 
-    def listener(self,ignore_filter=False):
+    def listener(self, ignore_filter=False):
         def decorator(func):
             self.add_listener(func.__name__, func)
             if ignore_filter:
@@ -160,10 +162,9 @@ class Bot:
             else:
                 await _m(query)
 
-    async def check_date(self,message):
-        date =  datetime.datetime.now()-datetime.timedelta(seconds=5)
-        return message.date>date
-
+    async def check_date(self, message):
+        date = datetime.datetime.now() - datetime.timedelta(seconds=5)
+        return message.date > date
 
     async def handleMessage(self, obj):
         self.offset = obj.get('update_id') + 1
@@ -173,8 +174,7 @@ class Bot:
                 return await self.dispatch(message)
         elif 'callback_query' in obj:
             query = CallbackQuery(self, obj.get('callback_query'))
-            if await self.check_date(query):
-                return await self.dispacth_query(query)
+            return await self.dispacth_query(query)
 
     def has_prefix(self, message):
         if message.text:
@@ -204,7 +204,7 @@ class Bot:
             for _m in self.listeners_handle.get('on_unknow_command'):
                 if _m in self.ignore_listener_filter or message.chat.id in self.chat_filter:
                     if _m in self.actions_from_cog:
-                        await _m(self,message)
+                        await _m(self, message)
                     else:
                         await _m(message)
 
@@ -247,11 +247,11 @@ class Bot:
                     else:
                         await _m(message)
 
-    async def dispatch_chat_filter_error(self,message):
+    async def dispatch_chat_filter_error(self, message):
         if self.listeners_handle.get('on_chat_filter'):
             for _m in self.listeners_handle.get('on_chat_filter'):
                 if _m in self.actions_from_cog:
-                    await _m(self,message)
+                    await _m(self, message)
                 else:
                     await _m(message)
 
@@ -263,16 +263,12 @@ class Bot:
         c = 0
         from_aliases = False
         for word in name.split():
-
             if word not in level:
                 break
+            c += 1
             level = level[word]
             if '' in level:
                 last_fitting = level['']
-                c += 1
-        if last_fitting is None and name in self.aliases:
-            last_fitting = self.aliases.get(name)
-            from_aliases = True
         return last_fitting, c, from_aliases
 
     def add_command(self, name, command):
@@ -287,7 +283,7 @@ class Bot:
         self.random_cog = cls
         for v in cls.__class__.__dict__.values():
             if '__command__' in dir(v):
-                command = Command(v,v.__command__)
+                command = Command(v, v.__command__)
                 if 'description' in dir(v):
                     command.description = v.description
                 if 'usage' in dir(v):
@@ -299,7 +295,7 @@ class Bot:
                 if 'aliases' in dir(v):
                     command.aliases = v.aliases
                     for al in v.aliases:
-                        self.add_command(al,command)
+                        self.add_command(al, command)
                 self.add_command(v.__command__, command)
                 self.actions_from_cog.append(command)
             elif '__listener__' in dir(v):
@@ -315,18 +311,19 @@ class Bot:
             rs, c, from_aliases = self.search(' '.join(ms))
             try:
                 if rs:
-                    if 'on_pre_command' in self.listeners_handle:
-                        for _m in self.listeners_handle.get('on_pre_command'):
-                            if _m in self.actions_from_cog:
-                                await _m(self,rs,message)
-                            else:
-                                await _m(rs,message)
-                    if len(self.chat_filter) > 0:
-                        if message.chat.id not in self.chat_filter and rs not in self.ignore_filter:
-                            return await self.dispatch_chat_filter_error(message)
                     for i in range(c):
                         ms.pop(0)
                     message.text = ' '.join(ms)
+                    setattr(message,'texts',ms)
+                    if 'on_pre_command' in self.listeners_handle:
+                        for _m in self.listeners_handle.get('on_pre_command'):
+                            if _m in self.actions_from_cog:
+                                await _m(self, rs, message)
+                            else:
+                                await _m(rs, message)
+                    if len(self.chat_filter) > 0:
+                        if message.chat.id not in self.chat_filter and rs not in self.ignore_filter:
+                            return await self.dispatch_chat_filter_error(message)
                     await self.dispatch_command(message, rs)
                 else:
                     await self.dispatch_uknow_command(message)
